;;; oni-conf.el --- Conf-mode configuration          -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 20190827215231
;; Package-Requires: (oni-yasnippet)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for the different ‘conf-mode’ variations.

;;; Code:

(require 'yasnippet)

(defconst oni-conf-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-conf’ was loaded from.")

(defconst oni-conf-snippets-dir
  (expand-file-name "snippets" oni-conf-root)
  "The directory where ‘oni-conf’ stores its snippets.")

;;;###autoload
(defun oni-conf-snippets-initialize ()
  "Initialize the snippets for ‘oni-conf’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-conf-snippets-dir t))
  (yas-load-directory oni-conf-snippets-dir))

;;;###autoload
(with-eval-after-load 'conf-mode
  (with-eval-after-load 'yasnippet
    (oni-conf-snippets-initialize)))

(provide 'oni-conf)
;;; oni-conf.el ends here
