;;; oni-java.el --- Java configuration               -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 20190723225257
;; Package-Requires: (oni-fci oni-data-dir lsp-java company-lsp lsp-ui hydra)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Java configuration.

;;; Code:

(require 'autoinsert)
(require 'hydra)
(require 'lsp-java)
(require 'oni-data-dir)

(defun oni-java-enable-buffer-formatting ()
  "Format the buffer before save."
  (add-hook 'before-save-hook 'lsp-format-buffer nil :local))

(defun oni-java-only-fill-comments ()
  "Set `comment-auto-fill-only-comments' to true locally."
  (setq-local comment-auto-fill-only-comments t))

(defhydra java-refactor-hydra (:color blue)
  ("r" lsp-rename "Rename object")
  ("m" lsp-java-extract-method "Extract method"))

(setq lsp-java-server-install-dir
      (oni-data-dir-locate "lsp-java/server/"))

(setq lsp-java-workspace-dir
      (oni-data-dir-locate "lsp-java/workspace/"))

(setq lsp-java-workspace-cache-dir
      (oni-data-dir-locate "lsp-java/workspace/cache/"))

(add-hook 'java-mode-hook #'oni-java-enable-buffer-formatting)
(add-hook 'java-mode-hook #'oni-java-only-fill-comments)
(add-hook 'java-mode-hook 'auto-fill-mode)
(add-hook 'java-mode-hook 'electric-indent-local-mode)
(add-hook 'java-mode-hook 'electric-pair-local-mode)
(add-hook 'java-mode-hook 'fci-mode)
(add-hook 'java-mode-hook 'lsp)

(add-to-list 'company-backends 'company-lsp)

(define-key java-mode-map (kbd "C-c r") 'java-refactor-hydra/body)

(add-to-list 'auto-insert-alist
             '("\\.java\\'"
               () "public class "
               (file-name-sans-extension
                (file-name-nondirectory (buffer-file-name))) " {\n"
                (indent-for-tab-command) _ "\n"
                "}"))

;;;###autoload(with-eval-after-load 'cc-mode (require 'oni-java))

(provide 'oni-java)
;;; oni-java.el ends here
